stack_data: Extract data from python stack frames and tracebacks for informative displays
=========================================================================================

Description
-----------

Extract data from python stack frames and tracebacks for informative displays

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/stack-data/

